@@ -1,6 +1,6 @@
 "dist.list" <-
 function() {
-  dist <- c("cau","exp","gam","gev","gld","glo","gno",
+  dist <- c("cau","exp","texp","gam","gev","gld","glo","gno",
             "gpa","gum","kap","kur","ln3","nor","pe3","ray",
             "revgum","rice","wak","wei");
   return(dist)
